/*
 * FILE:
 * duitxnquery.h
 *
 * FUNCTION:
 * Handler for database queries.  DuiFields are used to construct an
 * SQL query, and then run that query.  Running the query returns 
 * a set of records.  The resulting records can be pumpted into 
 * a different set of fields by using the DuiTxnReport structures.
 *
 * HISTORY:
 * Copyright (c) 2002, 2003 Linas Vepstas <linas@linas.org>
 */

#ifndef DUI_TXN_QUERY_H_
#define DUI_TXN_QUERY_H_

#include "config.h"

#include "database.h"
#include "dui-initdb.h"
#include "duifieldmap.h"
#include "duiresolver.h"

typedef struct DuiTxnQuery_s DuiTxnQuery;

DuiTxnQuery * dui_txnquery_new (void);
void dui_txnquery_destroy (DuiTxnQuery *q);

/* The 'tables' term needs to return the name of a valid SQL table */
/* XXX this should probably be another fieldmap term. 
 * holding query type in source and table name in target.
 */
void dui_txnquery_set_table (DuiTxnQuery *qry, DuiField *tables, 
                                      const char * sql_querytype);

/** Add a term to the SQL query.  
 * For SELECT field names, set the fieldmap target to DUI_FIELD_CONST.
 * For UPDATE field & new value, set the fieldmap target to DUI_FIELD_SQL.
 * For WHERE macthing terms, set the fieldmap target to DUI_FIELD_WHERE.
 */
void dui_txnquery_add_term (DuiTxnQuery *qry, DuiFieldMap *fm);

void dui_txnquery_set_resolver (DuiTxnQuery *qry, DuiResolver *);
void dui_txnquery_set_database (DuiTxnQuery * q, DuiDatabase *db);
	
void dui_txnquery_do_realize (DuiTxnQuery *qry);
void dui_txnquery_connect (DuiTxnQuery *qry);

DuiDBRecordSet * dui_txnquery_run (DuiTxnQuery *qry);
DuiDBRecordSet * dui_txnquery_rerun_last_query (DuiTxnQuery *qry);

/* XXX should try to ditch this routine */
DuiDatabase * dui_txnquery_get_database (DuiTxnQuery * q);

#endif /* DUI_DB_QUERY_H_ */
