/********************************************************************\
 * report.h --  Fill in widget values based on database query       *
 * Copyright (C) 2002 Linas Vepstas <linas@linas.org>               *
 * http://dwi.sourceforge.net                                       *
 *                                                                  *
 * This library is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU Lesser General Public       *
 * License as published by the Free Software Foundation; either     *
 * version 2.1 of the License, or (at your option) any later version.
 *                                                                  *
 * This library is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU Lesser General Public License for more details.              *
 *                                                                  *
 * You should have received a copy of the GNU Lesser General Public *
 * License along with this program; if not, contact:                *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 59 Temple Place - Suite 330        Fax:    +1-617-542-2652       *
 * Boston, MA  02111-1307,  USA       gnu@gnu.org                   *
\********************************************************************/
/*
 * FUNCTION:
 * Fill in widget values based on results of database query
 *
 * HISTORY:
 * Linas Vepstas March 2002
 */

#ifndef DUI_REPORT_H
#define DUI_REPORT_H

#include "dui-initdb.h"
#include "duifieldmap.h"
#include "interface.h"
#include "window.h"

DuiReport * dui_report_new (DuiWindow *, const char * name);
void dui_report_destroy (DuiReport *);

/* Add a row transaction.  This will typically hold a table widget,
 * sometimes just a collection of non-table widgets.
 * The "name" is used to identify this row as the target of an action.
 * If nest is non-zero, then the table widget must be capable of displaying
 * a tree.  'nest' is how far down the tree we are.  Nest is used to 
 * determine if we should clear the table before redrawing it. 
 */
void dui_report_add_row (DuiReport *, const char *name, int nest);

/** Add a report 'column'. The fieldmap target should probably contain
 * a widget into which data will be copied, possibly specifying a 
 * column of a widget.   The fieldmap source is probably going to 
 * be some SQL table column.
 */
void dui_report_add_term (DuiReport *rpt, DuiFieldMap *fm); 

void dui_report_do_realize (DuiReport *);
const char * dui_report_get_name (DuiReport *);

/* Pull data off the indicated connection and display it. 
 * The "row_name" argument is used to determine the order
 * in which heirarchical reports are filled in.
 * Returns a non-zero value if there was data and it was 
 * displayed.  If there was no data, then no GUI element
 * was displayed, and this retruns zero.
 */
int dui_report_show_data (DuiReport *, DuiDBRecordSet *, 
                           const char * row_name);

/* Set the most recent action that generated data for this window.
 * If this window need to be refreshed, then this action will be
 * used to refresh it.  The "row_name" argument allows this 
 * report to be the target of several actions, heirarchically nested.
 */
void dui_report_set_last_action (DuiReport *, DuiAction *, 
                                 const char *row_name);

void dui_report_refresh (DuiReport *);

#endif /* DUI_REPORT_H */
